"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ImageWidgetView = exports.ImageWidgetModel = void 0;
// Import the CSS
require("../css/widget.css");
require("../css/styles.css");
const base_1 = require("@jupyter-widgets/base");
const version_1 = require("./version");
// This file is not running under Google3/Blaze environment
// tslint:disable-next-line:no-require-imports
const mainJS = require('file-loader!./main.js');
const runtimeJS = require('file-loader!./runtime.js');
const polyfillsJS = require('file-loader!./polyfills.js');
const polyfillsES5JS = require('file-loader!./polyfills-es5.js');
const vendorJS = require('file-loader!./vendor.js');
// BEGIN OSS
const STYLES_HTML = '<link href="https://unpkg.com/@angular/material@9.0.0-rc.6/prebuilt-themes/indigo-pink.css" rel="stylesheet">';
// END OSS
// This is a standard of Jupyter Lab widget for syncing with python codes
// tslint:disable:enforce-name-casing
/** Widget model for storing information and sync with python part. */
class ImageWidgetModel extends base_1.DOMWidgetModel {
    defaults() {
        return Object.assign(Object.assign({}, super.defaults()), { _model_name: ImageWidgetModel.model_name, _model_module: ImageWidgetModel.model_module, _model_module_version: ImageWidgetModel.model_module_version, _view_name: ImageWidgetModel.view_name, _view_module: ImageWidgetModel.view_module, _view_module_version: ImageWidgetModel.view_module_version, description: 'A widget to visualize image attributions.', _data_url: '', _data_dict: {}, _metadata_url: '', _metadata_dict: {}, ready: false, latest_update: '' });
    }
}
exports.ImageWidgetModel = ImageWidgetModel;
ImageWidgetModel.serializers = Object.assign({}, base_1.DOMWidgetModel.serializers);
ImageWidgetModel.model_name = 'ImageWidgetModel';
ImageWidgetModel.model_module = version_1.MODULE_NAME;
ImageWidgetModel.model_module_version = version_1.MODULE_VERSION;
ImageWidgetModel.view_name = 'ImageWidgetView'; // Set to null if no view
ImageWidgetModel.view_module = version_1.MODULE_NAME; // Set to null if no view
ImageWidgetModel.view_module_version = version_1.MODULE_VERSION;
// tslint:enable:enforce-name-casing
/** Widget view for embedding the Angular app. */
class ImageWidgetView extends base_1.DOMWidgetView {
    constructor() {
        super(...arguments);
        this.iframeId = 'xai-image-widget-iframe-' + Math.random().toString().substring(2, 8);
    }
    render() {
        const self = this;
        const iframe = document.createElement('iframe');
        const app = `
        <!doctype html>
        <html lang="en">
        <head>
          <meta charset="utf-8">
          <title>XAI ImageWidget</title>
          <base href="/">

          <meta name="viewport" content="width=device-width, initial-scale=1">
          <link href="https://fonts.googleapis.com/css?family=Roboto:300,400,500&display=swap" rel="stylesheet">
          ${STYLES_HTML}
          <style type="text/css">
            html, body { height: 100%; }
            body { margin: 0; font-family: Roboto, "Helvetica Neue", sans-serif; }
          </style>
        </head>
        <body>
          <app-root></app-root>
          <script src="${mainJS}" type="module" defer></script>
<script src="${runtimeJS}" type="module" defer></script>
<script src="${polyfillsJS}" type="module" defer></script>
<script src="${polyfillsES5JS}" type="module" defer></script>
<script src="${vendorJS}" type="module" defer></script>

        </body>
    </html>

    `;
        iframe.id = self.iframeId;
        iframe.frameBorder = '0';
        iframe.style.width = '100%';
        iframe.style.height = '500px';
        iframe.srcdoc = app;
        self.iframe = iframe;
        self.el.appendChild(self.iframe);
        const model = self.model;
        model.on('change:_data_url', self.dataUrlChanged, self);
        model.on('change:_data_dict', self.dataDictChanged, self);
        model.on('change:latest_update', self.update, self);
        window.document.addEventListener('readyEvent', handleReadyEvent);
        function handleReadyEvent(e) {
            model.set('ready', true);
            model.save_changes();
            self.update();
        }
        window.document.addEventListener('iframeResizeEvent', handleIframeResizeEvent);
        function handleIframeResizeEvent(e) {
            if (isCustomEvent(e)) {
                iframe.style.height = `${e.detail}px`;
            }
        }
    }
    update() {
        const dataUrl = this.model.get('_data_url');
        const data = this.model.get('_data_dict');
        if (dataUrl.length > 0) {
            this.dataUrlChanged();
        }
        else if (data.hasOwnProperty('debug_raw_attribution_dict')) {
            this.dataDictChanged();
        }
    }
    dataUrlChanged() {
        const ifrmEle = this.el.querySelector('#' + this.iframeId);
        const ifrm = ifrmEle.contentDocument;
        if (ifrm !== null && this.model.get('_data_url').length > 0) {
            const e = new CustomEvent('loadDataFromUrlEvent', {
                detail: {
                    dataUrl: this.model.get('_data_url'),
                    metadataUrl: this.model.get('_metadata_url')
                }
            });
            ifrm.dispatchEvent(e);
        }
    }
    dataDictChanged() {
        const ifrmEle = this.el.querySelector('#' + this.iframeId);
        const ifrm = ifrmEle.contentDocument;
        const data = this.model.get('_data_dict');
        if (ifrm !== null && data.hasOwnProperty('debug_raw_attribution_dict')) {
            const e = new CustomEvent('loadDataFromDictEvent', {
                detail: {
                    data,
                    metadata: this.model.get('_metadata_dict')
                }
            });
            ifrm.dispatchEvent(e);
        }
    }
}
exports.ImageWidgetView = ImageWidgetView;
function isCustomEvent(event) {
    return 'detail' in event;
}
//# sourceMappingURL=widget.js.map